% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1114.104612528186635 ; 1115.048736071857547 ];

%-- Principal point:
cc = [ 509.453474507920873 ; 509.498349271098959 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.102515257170843 ; 0.112375983143232 ; 0.000044307291010 ; -0.003623927563337 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 3.941930992429142 ; 3.961284825687688 ];

%-- Principal point uncertainty:
cc_error = [ 4.403687107672836 ; 3.531629212914867 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.009951707672410 ; 0.049628886849801 ; 0.000828620701541 ; 0.000881294055026 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 291;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -3.063427e+00 ; 1.582768e-02 ; 4.779328e-05 ];
Tc_1  = [ -1.428469e+02 ; 4.195977e+01 ; 1.091089e+03 ];
omc_error_1 = [ 4.744912e-03 ; 6.590946e-04 ; 6.846777e-03 ];
Tc_error_1  = [ 4.310752e+00 ; 3.447022e+00 ; 4.038187e+00 ];

%-- Image #2:
omc_2 = [ NaN ; NaN ; NaN ];
Tc_2  = [ NaN ; NaN ; NaN ];
omc_error_2 = [ NaN ; NaN ; NaN ];
Tc_error_2  = [ NaN ; NaN ; NaN ];

%-- Image #3:
omc_3 = [ NaN ; NaN ; NaN ];
Tc_3  = [ NaN ; NaN ; NaN ];
omc_error_3 = [ NaN ; NaN ; NaN ];
Tc_error_3  = [ NaN ; NaN ; NaN ];

%-- Image #4:
omc_4 = [ NaN ; NaN ; NaN ];
Tc_4  = [ NaN ; NaN ; NaN ];
omc_error_4 = [ NaN ; NaN ; NaN ];
Tc_error_4  = [ NaN ; NaN ; NaN ];

%-- Image #5:
omc_5 = [ NaN ; NaN ; NaN ];
Tc_5  = [ NaN ; NaN ; NaN ];
omc_error_5 = [ NaN ; NaN ; NaN ];
Tc_error_5  = [ NaN ; NaN ; NaN ];

%-- Image #6:
omc_6 = [ NaN ; NaN ; NaN ];
Tc_6  = [ NaN ; NaN ; NaN ];
omc_error_6 = [ NaN ; NaN ; NaN ];
Tc_error_6  = [ NaN ; NaN ; NaN ];

%-- Image #7:
omc_7 = [ NaN ; NaN ; NaN ];
Tc_7  = [ NaN ; NaN ; NaN ];
omc_error_7 = [ NaN ; NaN ; NaN ];
Tc_error_7  = [ NaN ; NaN ; NaN ];

%-- Image #8:
omc_8 = [ NaN ; NaN ; NaN ];
Tc_8  = [ NaN ; NaN ; NaN ];
omc_error_8 = [ NaN ; NaN ; NaN ];
Tc_error_8  = [ NaN ; NaN ; NaN ];

%-- Image #9:
omc_9 = [ NaN ; NaN ; NaN ];
Tc_9  = [ NaN ; NaN ; NaN ];
omc_error_9 = [ NaN ; NaN ; NaN ];
Tc_error_9  = [ NaN ; NaN ; NaN ];

%-- Image #10:
omc_10 = [ NaN ; NaN ; NaN ];
Tc_10  = [ NaN ; NaN ; NaN ];
omc_error_10 = [ NaN ; NaN ; NaN ];
Tc_error_10  = [ NaN ; NaN ; NaN ];

%-- Image #11:
omc_11 = [ NaN ; NaN ; NaN ];
Tc_11  = [ NaN ; NaN ; NaN ];
omc_error_11 = [ NaN ; NaN ; NaN ];
Tc_error_11  = [ NaN ; NaN ; NaN ];

%-- Image #12:
omc_12 = [ NaN ; NaN ; NaN ];
Tc_12  = [ NaN ; NaN ; NaN ];
omc_error_12 = [ NaN ; NaN ; NaN ];
Tc_error_12  = [ NaN ; NaN ; NaN ];

%-- Image #13:
omc_13 = [ NaN ; NaN ; NaN ];
Tc_13  = [ NaN ; NaN ; NaN ];
omc_error_13 = [ NaN ; NaN ; NaN ];
Tc_error_13  = [ NaN ; NaN ; NaN ];

%-- Image #14:
omc_14 = [ NaN ; NaN ; NaN ];
Tc_14  = [ NaN ; NaN ; NaN ];
omc_error_14 = [ NaN ; NaN ; NaN ];
Tc_error_14  = [ NaN ; NaN ; NaN ];

%-- Image #15:
omc_15 = [ NaN ; NaN ; NaN ];
Tc_15  = [ NaN ; NaN ; NaN ];
omc_error_15 = [ NaN ; NaN ; NaN ];
Tc_error_15  = [ NaN ; NaN ; NaN ];

%-- Image #16:
omc_16 = [ -2.190472e+00 ; -2.170482e+00 ; -8.579127e-02 ];
Tc_16  = [ -1.448557e+02 ; -2.411571e+02 ; 1.068278e+03 ];
omc_error_16 = [ 3.235575e-03 ; 3.274057e-03 ; 7.208870e-03 ];
Tc_error_16  = [ 4.271320e+00 ; 3.414040e+00 ; 4.008418e+00 ];

%-- Image #17:
omc_17 = [ NaN ; NaN ; NaN ];
Tc_17  = [ NaN ; NaN ; NaN ];
omc_error_17 = [ NaN ; NaN ; NaN ];
Tc_error_17  = [ NaN ; NaN ; NaN ];

%-- Image #18:
omc_18 = [ NaN ; NaN ; NaN ];
Tc_18  = [ NaN ; NaN ; NaN ];
omc_error_18 = [ NaN ; NaN ; NaN ];
Tc_error_18  = [ NaN ; NaN ; NaN ];

%-- Image #19:
omc_19 = [ NaN ; NaN ; NaN ];
Tc_19  = [ NaN ; NaN ; NaN ];
omc_error_19 = [ NaN ; NaN ; NaN ];
Tc_error_19  = [ NaN ; NaN ; NaN ];

%-- Image #20:
omc_20 = [ NaN ; NaN ; NaN ];
Tc_20  = [ NaN ; NaN ; NaN ];
omc_error_20 = [ NaN ; NaN ; NaN ];
Tc_error_20  = [ NaN ; NaN ; NaN ];

%-- Image #21:
omc_21 = [ NaN ; NaN ; NaN ];
Tc_21  = [ NaN ; NaN ; NaN ];
omc_error_21 = [ NaN ; NaN ; NaN ];
Tc_error_21  = [ NaN ; NaN ; NaN ];

%-- Image #22:
omc_22 = [ NaN ; NaN ; NaN ];
Tc_22  = [ NaN ; NaN ; NaN ];
omc_error_22 = [ NaN ; NaN ; NaN ];
Tc_error_22  = [ NaN ; NaN ; NaN ];

%-- Image #23:
omc_23 = [ NaN ; NaN ; NaN ];
Tc_23  = [ NaN ; NaN ; NaN ];
omc_error_23 = [ NaN ; NaN ; NaN ];
Tc_error_23  = [ NaN ; NaN ; NaN ];

%-- Image #24:
omc_24 = [ NaN ; NaN ; NaN ];
Tc_24  = [ NaN ; NaN ; NaN ];
omc_error_24 = [ NaN ; NaN ; NaN ];
Tc_error_24  = [ NaN ; NaN ; NaN ];

%-- Image #25:
omc_25 = [ NaN ; NaN ; NaN ];
Tc_25  = [ NaN ; NaN ; NaN ];
omc_error_25 = [ NaN ; NaN ; NaN ];
Tc_error_25  = [ NaN ; NaN ; NaN ];

%-- Image #26:
omc_26 = [ NaN ; NaN ; NaN ];
Tc_26  = [ NaN ; NaN ; NaN ];
omc_error_26 = [ NaN ; NaN ; NaN ];
Tc_error_26  = [ NaN ; NaN ; NaN ];

%-- Image #27:
omc_27 = [ NaN ; NaN ; NaN ];
Tc_27  = [ NaN ; NaN ; NaN ];
omc_error_27 = [ NaN ; NaN ; NaN ];
Tc_error_27  = [ NaN ; NaN ; NaN ];

%-- Image #28:
omc_28 = [ NaN ; NaN ; NaN ];
Tc_28  = [ NaN ; NaN ; NaN ];
omc_error_28 = [ NaN ; NaN ; NaN ];
Tc_error_28  = [ NaN ; NaN ; NaN ];

%-- Image #29:
omc_29 = [ NaN ; NaN ; NaN ];
Tc_29  = [ NaN ; NaN ; NaN ];
omc_error_29 = [ NaN ; NaN ; NaN ];
Tc_error_29  = [ NaN ; NaN ; NaN ];

%-- Image #30:
omc_30 = [ NaN ; NaN ; NaN ];
Tc_30  = [ NaN ; NaN ; NaN ];
omc_error_30 = [ NaN ; NaN ; NaN ];
Tc_error_30  = [ NaN ; NaN ; NaN ];

%-- Image #31:
omc_31 = [ -2.195663e+00 ; -2.169536e+00 ; -7.351128e-02 ];
Tc_31  = [ -1.480076e+02 ; -2.436052e+02 ; 1.076194e+03 ];
omc_error_31 = [ 3.286706e-03 ; 3.285571e-03 ; 7.273001e-03 ];
Tc_error_31  = [ 4.301756e+00 ; 3.436826e+00 ; 4.040962e+00 ];

%-- Image #32:
omc_32 = [ NaN ; NaN ; NaN ];
Tc_32  = [ NaN ; NaN ; NaN ];
omc_error_32 = [ NaN ; NaN ; NaN ];
Tc_error_32  = [ NaN ; NaN ; NaN ];

%-- Image #33:
omc_33 = [ NaN ; NaN ; NaN ];
Tc_33  = [ NaN ; NaN ; NaN ];
omc_error_33 = [ NaN ; NaN ; NaN ];
Tc_error_33  = [ NaN ; NaN ; NaN ];

%-- Image #34:
omc_34 = [ NaN ; NaN ; NaN ];
Tc_34  = [ NaN ; NaN ; NaN ];
omc_error_34 = [ NaN ; NaN ; NaN ];
Tc_error_34  = [ NaN ; NaN ; NaN ];

%-- Image #35:
omc_35 = [ NaN ; NaN ; NaN ];
Tc_35  = [ NaN ; NaN ; NaN ];
omc_error_35 = [ NaN ; NaN ; NaN ];
Tc_error_35  = [ NaN ; NaN ; NaN ];

%-- Image #36:
omc_36 = [ NaN ; NaN ; NaN ];
Tc_36  = [ NaN ; NaN ; NaN ];
omc_error_36 = [ NaN ; NaN ; NaN ];
Tc_error_36  = [ NaN ; NaN ; NaN ];

%-- Image #37:
omc_37 = [ NaN ; NaN ; NaN ];
Tc_37  = [ NaN ; NaN ; NaN ];
omc_error_37 = [ NaN ; NaN ; NaN ];
Tc_error_37  = [ NaN ; NaN ; NaN ];

%-- Image #38:
omc_38 = [ NaN ; NaN ; NaN ];
Tc_38  = [ NaN ; NaN ; NaN ];
omc_error_38 = [ NaN ; NaN ; NaN ];
Tc_error_38  = [ NaN ; NaN ; NaN ];

%-- Image #39:
omc_39 = [ NaN ; NaN ; NaN ];
Tc_39  = [ NaN ; NaN ; NaN ];
omc_error_39 = [ NaN ; NaN ; NaN ];
Tc_error_39  = [ NaN ; NaN ; NaN ];

%-- Image #40:
omc_40 = [ NaN ; NaN ; NaN ];
Tc_40  = [ NaN ; NaN ; NaN ];
omc_error_40 = [ NaN ; NaN ; NaN ];
Tc_error_40  = [ NaN ; NaN ; NaN ];

%-- Image #41:
omc_41 = [ NaN ; NaN ; NaN ];
Tc_41  = [ NaN ; NaN ; NaN ];
omc_error_41 = [ NaN ; NaN ; NaN ];
Tc_error_41  = [ NaN ; NaN ; NaN ];

%-- Image #42:
omc_42 = [ NaN ; NaN ; NaN ];
Tc_42  = [ NaN ; NaN ; NaN ];
omc_error_42 = [ NaN ; NaN ; NaN ];
Tc_error_42  = [ NaN ; NaN ; NaN ];

%-- Image #43:
omc_43 = [ NaN ; NaN ; NaN ];
Tc_43  = [ NaN ; NaN ; NaN ];
omc_error_43 = [ NaN ; NaN ; NaN ];
Tc_error_43  = [ NaN ; NaN ; NaN ];

%-- Image #44:
omc_44 = [ NaN ; NaN ; NaN ];
Tc_44  = [ NaN ; NaN ; NaN ];
omc_error_44 = [ NaN ; NaN ; NaN ];
Tc_error_44  = [ NaN ; NaN ; NaN ];

%-- Image #45:
omc_45 = [ NaN ; NaN ; NaN ];
Tc_45  = [ NaN ; NaN ; NaN ];
omc_error_45 = [ NaN ; NaN ; NaN ];
Tc_error_45  = [ NaN ; NaN ; NaN ];

%-- Image #46:
omc_46 = [ -2.263792e+00 ; -2.178121e+00 ; 1.177271e-02 ];
Tc_46  = [ -1.577974e+02 ; -2.335294e+02 ; 1.070305e+03 ];
omc_error_46 = [ 3.225869e-03 ; 2.939175e-03 ; 6.983058e-03 ];
Tc_error_46  = [ 4.267442e+00 ; 3.390531e+00 ; 4.002462e+00 ];

%-- Image #47:
omc_47 = [ NaN ; NaN ; NaN ];
Tc_47  = [ NaN ; NaN ; NaN ];
omc_error_47 = [ NaN ; NaN ; NaN ];
Tc_error_47  = [ NaN ; NaN ; NaN ];

%-- Image #48:
omc_48 = [ NaN ; NaN ; NaN ];
Tc_48  = [ NaN ; NaN ; NaN ];
omc_error_48 = [ NaN ; NaN ; NaN ];
Tc_error_48  = [ NaN ; NaN ; NaN ];

%-- Image #49:
omc_49 = [ NaN ; NaN ; NaN ];
Tc_49  = [ NaN ; NaN ; NaN ];
omc_error_49 = [ NaN ; NaN ; NaN ];
Tc_error_49  = [ NaN ; NaN ; NaN ];

%-- Image #50:
omc_50 = [ NaN ; NaN ; NaN ];
Tc_50  = [ NaN ; NaN ; NaN ];
omc_error_50 = [ NaN ; NaN ; NaN ];
Tc_error_50  = [ NaN ; NaN ; NaN ];

%-- Image #51:
omc_51 = [ NaN ; NaN ; NaN ];
Tc_51  = [ NaN ; NaN ; NaN ];
omc_error_51 = [ NaN ; NaN ; NaN ];
Tc_error_51  = [ NaN ; NaN ; NaN ];

%-- Image #52:
omc_52 = [ NaN ; NaN ; NaN ];
Tc_52  = [ NaN ; NaN ; NaN ];
omc_error_52 = [ NaN ; NaN ; NaN ];
Tc_error_52  = [ NaN ; NaN ; NaN ];

%-- Image #53:
omc_53 = [ NaN ; NaN ; NaN ];
Tc_53  = [ NaN ; NaN ; NaN ];
omc_error_53 = [ NaN ; NaN ; NaN ];
Tc_error_53  = [ NaN ; NaN ; NaN ];

%-- Image #54:
omc_54 = [ NaN ; NaN ; NaN ];
Tc_54  = [ NaN ; NaN ; NaN ];
omc_error_54 = [ NaN ; NaN ; NaN ];
Tc_error_54  = [ NaN ; NaN ; NaN ];

%-- Image #55:
omc_55 = [ NaN ; NaN ; NaN ];
Tc_55  = [ NaN ; NaN ; NaN ];
omc_error_55 = [ NaN ; NaN ; NaN ];
Tc_error_55  = [ NaN ; NaN ; NaN ];

%-- Image #56:
omc_56 = [ NaN ; NaN ; NaN ];
Tc_56  = [ NaN ; NaN ; NaN ];
omc_error_56 = [ NaN ; NaN ; NaN ];
Tc_error_56  = [ NaN ; NaN ; NaN ];

%-- Image #57:
omc_57 = [ NaN ; NaN ; NaN ];
Tc_57  = [ NaN ; NaN ; NaN ];
omc_error_57 = [ NaN ; NaN ; NaN ];
Tc_error_57  = [ NaN ; NaN ; NaN ];

%-- Image #58:
omc_58 = [ NaN ; NaN ; NaN ];
Tc_58  = [ NaN ; NaN ; NaN ];
omc_error_58 = [ NaN ; NaN ; NaN ];
Tc_error_58  = [ NaN ; NaN ; NaN ];

%-- Image #59:
omc_59 = [ NaN ; NaN ; NaN ];
Tc_59  = [ NaN ; NaN ; NaN ];
omc_error_59 = [ NaN ; NaN ; NaN ];
Tc_error_59  = [ NaN ; NaN ; NaN ];

%-- Image #60:
omc_60 = [ NaN ; NaN ; NaN ];
Tc_60  = [ NaN ; NaN ; NaN ];
omc_error_60 = [ NaN ; NaN ; NaN ];
Tc_error_60  = [ NaN ; NaN ; NaN ];

%-- Image #61:
omc_61 = [ -2.264822e+00 ; -2.159609e+00 ; 6.653257e-02 ];
Tc_61  = [ -1.722898e+02 ; -2.399425e+02 ; 8.523983e+02 ];
omc_error_61 = [ 2.743972e-03 ; 2.296548e-03 ; 5.658790e-03 ];
Tc_error_61  = [ 3.410784e+00 ; 2.692782e+00 ; 3.209975e+00 ];

%-- Image #62:
omc_62 = [ NaN ; NaN ; NaN ];
Tc_62  = [ NaN ; NaN ; NaN ];
omc_error_62 = [ NaN ; NaN ; NaN ];
Tc_error_62  = [ NaN ; NaN ; NaN ];

%-- Image #63:
omc_63 = [ NaN ; NaN ; NaN ];
Tc_63  = [ NaN ; NaN ; NaN ];
omc_error_63 = [ NaN ; NaN ; NaN ];
Tc_error_63  = [ NaN ; NaN ; NaN ];

%-- Image #64:
omc_64 = [ NaN ; NaN ; NaN ];
Tc_64  = [ NaN ; NaN ; NaN ];
omc_error_64 = [ NaN ; NaN ; NaN ];
Tc_error_64  = [ NaN ; NaN ; NaN ];

%-- Image #65:
omc_65 = [ NaN ; NaN ; NaN ];
Tc_65  = [ NaN ; NaN ; NaN ];
omc_error_65 = [ NaN ; NaN ; NaN ];
Tc_error_65  = [ NaN ; NaN ; NaN ];

%-- Image #66:
omc_66 = [ NaN ; NaN ; NaN ];
Tc_66  = [ NaN ; NaN ; NaN ];
omc_error_66 = [ NaN ; NaN ; NaN ];
Tc_error_66  = [ NaN ; NaN ; NaN ];

%-- Image #67:
omc_67 = [ NaN ; NaN ; NaN ];
Tc_67  = [ NaN ; NaN ; NaN ];
omc_error_67 = [ NaN ; NaN ; NaN ];
Tc_error_67  = [ NaN ; NaN ; NaN ];

%-- Image #68:
omc_68 = [ NaN ; NaN ; NaN ];
Tc_68  = [ NaN ; NaN ; NaN ];
omc_error_68 = [ NaN ; NaN ; NaN ];
Tc_error_68  = [ NaN ; NaN ; NaN ];

%-- Image #69:
omc_69 = [ NaN ; NaN ; NaN ];
Tc_69  = [ NaN ; NaN ; NaN ];
omc_error_69 = [ NaN ; NaN ; NaN ];
Tc_error_69  = [ NaN ; NaN ; NaN ];

%-- Image #70:
omc_70 = [ NaN ; NaN ; NaN ];
Tc_70  = [ NaN ; NaN ; NaN ];
omc_error_70 = [ NaN ; NaN ; NaN ];
Tc_error_70  = [ NaN ; NaN ; NaN ];

%-- Image #71:
omc_71 = [ NaN ; NaN ; NaN ];
Tc_71  = [ NaN ; NaN ; NaN ];
omc_error_71 = [ NaN ; NaN ; NaN ];
Tc_error_71  = [ NaN ; NaN ; NaN ];

%-- Image #72:
omc_72 = [ NaN ; NaN ; NaN ];
Tc_72  = [ NaN ; NaN ; NaN ];
omc_error_72 = [ NaN ; NaN ; NaN ];
Tc_error_72  = [ NaN ; NaN ; NaN ];

%-- Image #73:
omc_73 = [ NaN ; NaN ; NaN ];
Tc_73  = [ NaN ; NaN ; NaN ];
omc_error_73 = [ NaN ; NaN ; NaN ];
Tc_error_73  = [ NaN ; NaN ; NaN ];

%-- Image #74:
omc_74 = [ NaN ; NaN ; NaN ];
Tc_74  = [ NaN ; NaN ; NaN ];
omc_error_74 = [ NaN ; NaN ; NaN ];
Tc_error_74  = [ NaN ; NaN ; NaN ];

%-- Image #75:
omc_75 = [ NaN ; NaN ; NaN ];
Tc_75  = [ NaN ; NaN ; NaN ];
omc_error_75 = [ NaN ; NaN ; NaN ];
Tc_error_75  = [ NaN ; NaN ; NaN ];

%-- Image #76:
omc_76 = [ -2.201127e+00 ; -2.135831e+00 ; -3.109400e-02 ];
Tc_76  = [ -1.750375e+02 ; -2.336671e+02 ; 8.799003e+02 ];
omc_error_76 = [ 2.642729e-03 ; 2.550474e-03 ; 5.887708e-03 ];
Tc_error_76  = [ 3.524433e+00 ; 2.812076e+00 ; 3.312501e+00 ];

%-- Image #77:
omc_77 = [ NaN ; NaN ; NaN ];
Tc_77  = [ NaN ; NaN ; NaN ];
omc_error_77 = [ NaN ; NaN ; NaN ];
Tc_error_77  = [ NaN ; NaN ; NaN ];

%-- Image #78:
omc_78 = [ NaN ; NaN ; NaN ];
Tc_78  = [ NaN ; NaN ; NaN ];
omc_error_78 = [ NaN ; NaN ; NaN ];
Tc_error_78  = [ NaN ; NaN ; NaN ];

%-- Image #79:
omc_79 = [ NaN ; NaN ; NaN ];
Tc_79  = [ NaN ; NaN ; NaN ];
omc_error_79 = [ NaN ; NaN ; NaN ];
Tc_error_79  = [ NaN ; NaN ; NaN ];

%-- Image #80:
omc_80 = [ NaN ; NaN ; NaN ];
Tc_80  = [ NaN ; NaN ; NaN ];
omc_error_80 = [ NaN ; NaN ; NaN ];
Tc_error_80  = [ NaN ; NaN ; NaN ];

%-- Image #81:
omc_81 = [ NaN ; NaN ; NaN ];
Tc_81  = [ NaN ; NaN ; NaN ];
omc_error_81 = [ NaN ; NaN ; NaN ];
Tc_error_81  = [ NaN ; NaN ; NaN ];

%-- Image #82:
omc_82 = [ NaN ; NaN ; NaN ];
Tc_82  = [ NaN ; NaN ; NaN ];
omc_error_82 = [ NaN ; NaN ; NaN ];
Tc_error_82  = [ NaN ; NaN ; NaN ];

%-- Image #83:
omc_83 = [ NaN ; NaN ; NaN ];
Tc_83  = [ NaN ; NaN ; NaN ];
omc_error_83 = [ NaN ; NaN ; NaN ];
Tc_error_83  = [ NaN ; NaN ; NaN ];

%-- Image #84:
omc_84 = [ NaN ; NaN ; NaN ];
Tc_84  = [ NaN ; NaN ; NaN ];
omc_error_84 = [ NaN ; NaN ; NaN ];
Tc_error_84  = [ NaN ; NaN ; NaN ];

%-- Image #85:
omc_85 = [ NaN ; NaN ; NaN ];
Tc_85  = [ NaN ; NaN ; NaN ];
omc_error_85 = [ NaN ; NaN ; NaN ];
Tc_error_85  = [ NaN ; NaN ; NaN ];

%-- Image #86:
omc_86 = [ NaN ; NaN ; NaN ];
Tc_86  = [ NaN ; NaN ; NaN ];
omc_error_86 = [ NaN ; NaN ; NaN ];
Tc_error_86  = [ NaN ; NaN ; NaN ];

%-- Image #87:
omc_87 = [ NaN ; NaN ; NaN ];
Tc_87  = [ NaN ; NaN ; NaN ];
omc_error_87 = [ NaN ; NaN ; NaN ];
Tc_error_87  = [ NaN ; NaN ; NaN ];

%-- Image #88:
omc_88 = [ NaN ; NaN ; NaN ];
Tc_88  = [ NaN ; NaN ; NaN ];
omc_error_88 = [ NaN ; NaN ; NaN ];
Tc_error_88  = [ NaN ; NaN ; NaN ];

%-- Image #89:
omc_89 = [ NaN ; NaN ; NaN ];
Tc_89  = [ NaN ; NaN ; NaN ];
omc_error_89 = [ NaN ; NaN ; NaN ];
Tc_error_89  = [ NaN ; NaN ; NaN ];

%-- Image #90:
omc_90 = [ NaN ; NaN ; NaN ];
Tc_90  = [ NaN ; NaN ; NaN ];
omc_error_90 = [ NaN ; NaN ; NaN ];
Tc_error_90  = [ NaN ; NaN ; NaN ];

%-- Image #91:
omc_91 = [ -2.190589e+00 ; -2.120930e+00 ; -7.961204e-02 ];
Tc_91  = [ -1.653319e+02 ; -2.291396e+02 ; 1.157607e+03 ];
omc_error_91 = [ 3.659479e-03 ; 3.677827e-03 ; 8.120930e-03 ];
Tc_error_91  = [ 4.616305e+00 ; 3.700653e+00 ; 4.352419e+00 ];

%-- Image #92:
omc_92 = [ NaN ; NaN ; NaN ];
Tc_92  = [ NaN ; NaN ; NaN ];
omc_error_92 = [ NaN ; NaN ; NaN ];
Tc_error_92  = [ NaN ; NaN ; NaN ];

%-- Image #93:
omc_93 = [ NaN ; NaN ; NaN ];
Tc_93  = [ NaN ; NaN ; NaN ];
omc_error_93 = [ NaN ; NaN ; NaN ];
Tc_error_93  = [ NaN ; NaN ; NaN ];

%-- Image #94:
omc_94 = [ NaN ; NaN ; NaN ];
Tc_94  = [ NaN ; NaN ; NaN ];
omc_error_94 = [ NaN ; NaN ; NaN ];
Tc_error_94  = [ NaN ; NaN ; NaN ];

%-- Image #95:
omc_95 = [ NaN ; NaN ; NaN ];
Tc_95  = [ NaN ; NaN ; NaN ];
omc_error_95 = [ NaN ; NaN ; NaN ];
Tc_error_95  = [ NaN ; NaN ; NaN ];

%-- Image #96:
omc_96 = [ NaN ; NaN ; NaN ];
Tc_96  = [ NaN ; NaN ; NaN ];
omc_error_96 = [ NaN ; NaN ; NaN ];
Tc_error_96  = [ NaN ; NaN ; NaN ];

%-- Image #97:
omc_97 = [ NaN ; NaN ; NaN ];
Tc_97  = [ NaN ; NaN ; NaN ];
omc_error_97 = [ NaN ; NaN ; NaN ];
Tc_error_97  = [ NaN ; NaN ; NaN ];

%-- Image #98:
omc_98 = [ NaN ; NaN ; NaN ];
Tc_98  = [ NaN ; NaN ; NaN ];
omc_error_98 = [ NaN ; NaN ; NaN ];
Tc_error_98  = [ NaN ; NaN ; NaN ];

%-- Image #99:
omc_99 = [ NaN ; NaN ; NaN ];
Tc_99  = [ NaN ; NaN ; NaN ];
omc_error_99 = [ NaN ; NaN ; NaN ];
Tc_error_99  = [ NaN ; NaN ; NaN ];

%-- Image #100:
omc_100 = [ NaN ; NaN ; NaN ];
Tc_100  = [ NaN ; NaN ; NaN ];
omc_error_100 = [ NaN ; NaN ; NaN ];
Tc_error_100  = [ NaN ; NaN ; NaN ];

%-- Image #101:
omc_101 = [ NaN ; NaN ; NaN ];
Tc_101  = [ NaN ; NaN ; NaN ];
omc_error_101 = [ NaN ; NaN ; NaN ];
Tc_error_101  = [ NaN ; NaN ; NaN ];

%-- Image #102:
omc_102 = [ NaN ; NaN ; NaN ];
Tc_102  = [ NaN ; NaN ; NaN ];
omc_error_102 = [ NaN ; NaN ; NaN ];
Tc_error_102  = [ NaN ; NaN ; NaN ];

%-- Image #103:
omc_103 = [ NaN ; NaN ; NaN ];
Tc_103  = [ NaN ; NaN ; NaN ];
omc_error_103 = [ NaN ; NaN ; NaN ];
Tc_error_103  = [ NaN ; NaN ; NaN ];

%-- Image #104:
omc_104 = [ NaN ; NaN ; NaN ];
Tc_104  = [ NaN ; NaN ; NaN ];
omc_error_104 = [ NaN ; NaN ; NaN ];
Tc_error_104  = [ NaN ; NaN ; NaN ];

%-- Image #105:
omc_105 = [ NaN ; NaN ; NaN ];
Tc_105  = [ NaN ; NaN ; NaN ];
omc_error_105 = [ NaN ; NaN ; NaN ];
Tc_error_105  = [ NaN ; NaN ; NaN ];

%-- Image #106:
omc_106 = [ 2.275327e+00 ; 2.145687e+00 ; 1.836586e-01 ];
Tc_106  = [ -1.664977e+02 ; -2.220290e+02 ; 1.305681e+03 ];
omc_error_106 = [ 3.917872e-03 ; 3.727210e-03 ; 8.621158e-03 ];
Tc_error_106  = [ 5.212800e+00 ; 4.157934e+00 ; 4.984516e+00 ];

%-- Image #107:
omc_107 = [ NaN ; NaN ; NaN ];
Tc_107  = [ NaN ; NaN ; NaN ];
omc_error_107 = [ NaN ; NaN ; NaN ];
Tc_error_107  = [ NaN ; NaN ; NaN ];

%-- Image #108:
omc_108 = [ NaN ; NaN ; NaN ];
Tc_108  = [ NaN ; NaN ; NaN ];
omc_error_108 = [ NaN ; NaN ; NaN ];
Tc_error_108  = [ NaN ; NaN ; NaN ];

%-- Image #109:
omc_109 = [ NaN ; NaN ; NaN ];
Tc_109  = [ NaN ; NaN ; NaN ];
omc_error_109 = [ NaN ; NaN ; NaN ];
Tc_error_109  = [ NaN ; NaN ; NaN ];

%-- Image #110:
omc_110 = [ NaN ; NaN ; NaN ];
Tc_110  = [ NaN ; NaN ; NaN ];
omc_error_110 = [ NaN ; NaN ; NaN ];
Tc_error_110  = [ NaN ; NaN ; NaN ];

%-- Image #111:
omc_111 = [ NaN ; NaN ; NaN ];
Tc_111  = [ NaN ; NaN ; NaN ];
omc_error_111 = [ NaN ; NaN ; NaN ];
Tc_error_111  = [ NaN ; NaN ; NaN ];

%-- Image #112:
omc_112 = [ NaN ; NaN ; NaN ];
Tc_112  = [ NaN ; NaN ; NaN ];
omc_error_112 = [ NaN ; NaN ; NaN ];
Tc_error_112  = [ NaN ; NaN ; NaN ];

%-- Image #113:
omc_113 = [ NaN ; NaN ; NaN ];
Tc_113  = [ NaN ; NaN ; NaN ];
omc_error_113 = [ NaN ; NaN ; NaN ];
Tc_error_113  = [ NaN ; NaN ; NaN ];

%-- Image #114:
omc_114 = [ NaN ; NaN ; NaN ];
Tc_114  = [ NaN ; NaN ; NaN ];
omc_error_114 = [ NaN ; NaN ; NaN ];
Tc_error_114  = [ NaN ; NaN ; NaN ];

%-- Image #115:
omc_115 = [ NaN ; NaN ; NaN ];
Tc_115  = [ NaN ; NaN ; NaN ];
omc_error_115 = [ NaN ; NaN ; NaN ];
Tc_error_115  = [ NaN ; NaN ; NaN ];

%-- Image #116:
omc_116 = [ NaN ; NaN ; NaN ];
Tc_116  = [ NaN ; NaN ; NaN ];
omc_error_116 = [ NaN ; NaN ; NaN ];
Tc_error_116  = [ NaN ; NaN ; NaN ];

%-- Image #117:
omc_117 = [ NaN ; NaN ; NaN ];
Tc_117  = [ NaN ; NaN ; NaN ];
omc_error_117 = [ NaN ; NaN ; NaN ];
Tc_error_117  = [ NaN ; NaN ; NaN ];

%-- Image #118:
omc_118 = [ NaN ; NaN ; NaN ];
Tc_118  = [ NaN ; NaN ; NaN ];
omc_error_118 = [ NaN ; NaN ; NaN ];
Tc_error_118  = [ NaN ; NaN ; NaN ];

%-- Image #119:
omc_119 = [ NaN ; NaN ; NaN ];
Tc_119  = [ NaN ; NaN ; NaN ];
omc_error_119 = [ NaN ; NaN ; NaN ];
Tc_error_119  = [ NaN ; NaN ; NaN ];

%-- Image #120:
omc_120 = [ NaN ; NaN ; NaN ];
Tc_120  = [ NaN ; NaN ; NaN ];
omc_error_120 = [ NaN ; NaN ; NaN ];
Tc_error_120  = [ NaN ; NaN ; NaN ];

%-- Image #121:
omc_121 = [ 1.968993e+00 ; 1.882383e+00 ; 7.066968e-01 ];
Tc_121  = [ -1.450504e+02 ; -2.207348e+02 ; 1.085196e+03 ];
omc_error_121 = [ 3.328839e-03 ; 2.609530e-03 ; 5.138242e-03 ];
Tc_error_121  = [ 4.348137e+00 ; 3.443446e+00 ; 4.359910e+00 ];

%-- Image #122:
omc_122 = [ NaN ; NaN ; NaN ];
Tc_122  = [ NaN ; NaN ; NaN ];
omc_error_122 = [ NaN ; NaN ; NaN ];
Tc_error_122  = [ NaN ; NaN ; NaN ];

%-- Image #123:
omc_123 = [ NaN ; NaN ; NaN ];
Tc_123  = [ NaN ; NaN ; NaN ];
omc_error_123 = [ NaN ; NaN ; NaN ];
Tc_error_123  = [ NaN ; NaN ; NaN ];

%-- Image #124:
omc_124 = [ NaN ; NaN ; NaN ];
Tc_124  = [ NaN ; NaN ; NaN ];
omc_error_124 = [ NaN ; NaN ; NaN ];
Tc_error_124  = [ NaN ; NaN ; NaN ];

%-- Image #125:
omc_125 = [ NaN ; NaN ; NaN ];
Tc_125  = [ NaN ; NaN ; NaN ];
omc_error_125 = [ NaN ; NaN ; NaN ];
Tc_error_125  = [ NaN ; NaN ; NaN ];

%-- Image #126:
omc_126 = [ NaN ; NaN ; NaN ];
Tc_126  = [ NaN ; NaN ; NaN ];
omc_error_126 = [ NaN ; NaN ; NaN ];
Tc_error_126  = [ NaN ; NaN ; NaN ];

%-- Image #127:
omc_127 = [ NaN ; NaN ; NaN ];
Tc_127  = [ NaN ; NaN ; NaN ];
omc_error_127 = [ NaN ; NaN ; NaN ];
Tc_error_127  = [ NaN ; NaN ; NaN ];

%-- Image #128:
omc_128 = [ NaN ; NaN ; NaN ];
Tc_128  = [ NaN ; NaN ; NaN ];
omc_error_128 = [ NaN ; NaN ; NaN ];
Tc_error_128  = [ NaN ; NaN ; NaN ];

%-- Image #129:
omc_129 = [ NaN ; NaN ; NaN ];
Tc_129  = [ NaN ; NaN ; NaN ];
omc_error_129 = [ NaN ; NaN ; NaN ];
Tc_error_129  = [ NaN ; NaN ; NaN ];

%-- Image #130:
omc_130 = [ NaN ; NaN ; NaN ];
Tc_130  = [ NaN ; NaN ; NaN ];
omc_error_130 = [ NaN ; NaN ; NaN ];
Tc_error_130  = [ NaN ; NaN ; NaN ];

%-- Image #131:
omc_131 = [ NaN ; NaN ; NaN ];
Tc_131  = [ NaN ; NaN ; NaN ];
omc_error_131 = [ NaN ; NaN ; NaN ];
Tc_error_131  = [ NaN ; NaN ; NaN ];

%-- Image #132:
omc_132 = [ NaN ; NaN ; NaN ];
Tc_132  = [ NaN ; NaN ; NaN ];
omc_error_132 = [ NaN ; NaN ; NaN ];
Tc_error_132  = [ NaN ; NaN ; NaN ];

%-- Image #133:
omc_133 = [ NaN ; NaN ; NaN ];
Tc_133  = [ NaN ; NaN ; NaN ];
omc_error_133 = [ NaN ; NaN ; NaN ];
Tc_error_133  = [ NaN ; NaN ; NaN ];

%-- Image #134:
omc_134 = [ NaN ; NaN ; NaN ];
Tc_134  = [ NaN ; NaN ; NaN ];
omc_error_134 = [ NaN ; NaN ; NaN ];
Tc_error_134  = [ NaN ; NaN ; NaN ];

%-- Image #135:
omc_135 = [ NaN ; NaN ; NaN ];
Tc_135  = [ NaN ; NaN ; NaN ];
omc_error_135 = [ NaN ; NaN ; NaN ];
Tc_error_135  = [ NaN ; NaN ; NaN ];

%-- Image #136:
omc_136 = [ NaN ; NaN ; NaN ];
Tc_136  = [ NaN ; NaN ; NaN ];
omc_error_136 = [ NaN ; NaN ; NaN ];
Tc_error_136  = [ NaN ; NaN ; NaN ];

%-- Image #137:
omc_137 = [ NaN ; NaN ; NaN ];
Tc_137  = [ NaN ; NaN ; NaN ];
omc_error_137 = [ NaN ; NaN ; NaN ];
Tc_error_137  = [ NaN ; NaN ; NaN ];

%-- Image #138:
omc_138 = [ NaN ; NaN ; NaN ];
Tc_138  = [ NaN ; NaN ; NaN ];
omc_error_138 = [ NaN ; NaN ; NaN ];
Tc_error_138  = [ NaN ; NaN ; NaN ];

%-- Image #139:
omc_139 = [ NaN ; NaN ; NaN ];
Tc_139  = [ NaN ; NaN ; NaN ];
omc_error_139 = [ NaN ; NaN ; NaN ];
Tc_error_139  = [ NaN ; NaN ; NaN ];

%-- Image #140:
omc_140 = [ NaN ; NaN ; NaN ];
Tc_140  = [ NaN ; NaN ; NaN ];
omc_error_140 = [ NaN ; NaN ; NaN ];
Tc_error_140  = [ NaN ; NaN ; NaN ];

%-- Image #141:
omc_141 = [ NaN ; NaN ; NaN ];
Tc_141  = [ NaN ; NaN ; NaN ];
omc_error_141 = [ NaN ; NaN ; NaN ];
Tc_error_141  = [ NaN ; NaN ; NaN ];

%-- Image #142:
omc_142 = [ NaN ; NaN ; NaN ];
Tc_142  = [ NaN ; NaN ; NaN ];
omc_error_142 = [ NaN ; NaN ; NaN ];
Tc_error_142  = [ NaN ; NaN ; NaN ];

%-- Image #143:
omc_143 = [ NaN ; NaN ; NaN ];
Tc_143  = [ NaN ; NaN ; NaN ];
omc_error_143 = [ NaN ; NaN ; NaN ];
Tc_error_143  = [ NaN ; NaN ; NaN ];

%-- Image #144:
omc_144 = [ NaN ; NaN ; NaN ];
Tc_144  = [ NaN ; NaN ; NaN ];
omc_error_144 = [ NaN ; NaN ; NaN ];
Tc_error_144  = [ NaN ; NaN ; NaN ];

%-- Image #145:
omc_145 = [ NaN ; NaN ; NaN ];
Tc_145  = [ NaN ; NaN ; NaN ];
omc_error_145 = [ NaN ; NaN ; NaN ];
Tc_error_145  = [ NaN ; NaN ; NaN ];

%-- Image #146:
omc_146 = [ NaN ; NaN ; NaN ];
Tc_146  = [ NaN ; NaN ; NaN ];
omc_error_146 = [ NaN ; NaN ; NaN ];
Tc_error_146  = [ NaN ; NaN ; NaN ];

%-- Image #147:
omc_147 = [ NaN ; NaN ; NaN ];
Tc_147  = [ NaN ; NaN ; NaN ];
omc_error_147 = [ NaN ; NaN ; NaN ];
Tc_error_147  = [ NaN ; NaN ; NaN ];

%-- Image #148:
omc_148 = [ NaN ; NaN ; NaN ];
Tc_148  = [ NaN ; NaN ; NaN ];
omc_error_148 = [ NaN ; NaN ; NaN ];
Tc_error_148  = [ NaN ; NaN ; NaN ];

%-- Image #149:
omc_149 = [ NaN ; NaN ; NaN ];
Tc_149  = [ NaN ; NaN ; NaN ];
omc_error_149 = [ NaN ; NaN ; NaN ];
Tc_error_149  = [ NaN ; NaN ; NaN ];

%-- Image #150:
omc_150 = [ NaN ; NaN ; NaN ];
Tc_150  = [ NaN ; NaN ; NaN ];
omc_error_150 = [ NaN ; NaN ; NaN ];
Tc_error_150  = [ NaN ; NaN ; NaN ];

%-- Image #151:
omc_151 = [ 1.911555e+00 ; 1.688551e+00 ; 7.828947e-01 ];
Tc_151  = [ -1.192412e+02 ; -2.166171e+02 ; 1.010142e+03 ];
omc_error_151 = [ 3.387491e-03 ; 2.658663e-03 ; 4.704838e-03 ];
Tc_error_151  = [ 4.048289e+00 ; 3.202955e+00 ; 4.136260e+00 ];

%-- Image #152:
omc_152 = [ NaN ; NaN ; NaN ];
Tc_152  = [ NaN ; NaN ; NaN ];
omc_error_152 = [ NaN ; NaN ; NaN ];
Tc_error_152  = [ NaN ; NaN ; NaN ];

%-- Image #153:
omc_153 = [ NaN ; NaN ; NaN ];
Tc_153  = [ NaN ; NaN ; NaN ];
omc_error_153 = [ NaN ; NaN ; NaN ];
Tc_error_153  = [ NaN ; NaN ; NaN ];

%-- Image #154:
omc_154 = [ NaN ; NaN ; NaN ];
Tc_154  = [ NaN ; NaN ; NaN ];
omc_error_154 = [ NaN ; NaN ; NaN ];
Tc_error_154  = [ NaN ; NaN ; NaN ];

%-- Image #155:
omc_155 = [ NaN ; NaN ; NaN ];
Tc_155  = [ NaN ; NaN ; NaN ];
omc_error_155 = [ NaN ; NaN ; NaN ];
Tc_error_155  = [ NaN ; NaN ; NaN ];

%-- Image #156:
omc_156 = [ NaN ; NaN ; NaN ];
Tc_156  = [ NaN ; NaN ; NaN ];
omc_error_156 = [ NaN ; NaN ; NaN ];
Tc_error_156  = [ NaN ; NaN ; NaN ];

%-- Image #157:
omc_157 = [ NaN ; NaN ; NaN ];
Tc_157  = [ NaN ; NaN ; NaN ];
omc_error_157 = [ NaN ; NaN ; NaN ];
Tc_error_157  = [ NaN ; NaN ; NaN ];

%-- Image #158:
omc_158 = [ NaN ; NaN ; NaN ];
Tc_158  = [ NaN ; NaN ; NaN ];
omc_error_158 = [ NaN ; NaN ; NaN ];
Tc_error_158  = [ NaN ; NaN ; NaN ];

%-- Image #159:
omc_159 = [ NaN ; NaN ; NaN ];
Tc_159  = [ NaN ; NaN ; NaN ];
omc_error_159 = [ NaN ; NaN ; NaN ];
Tc_error_159  = [ NaN ; NaN ; NaN ];

%-- Image #160:
omc_160 = [ NaN ; NaN ; NaN ];
Tc_160  = [ NaN ; NaN ; NaN ];
omc_error_160 = [ NaN ; NaN ; NaN ];
Tc_error_160  = [ NaN ; NaN ; NaN ];

%-- Image #161:
omc_161 = [ NaN ; NaN ; NaN ];
Tc_161  = [ NaN ; NaN ; NaN ];
omc_error_161 = [ NaN ; NaN ; NaN ];
Tc_error_161  = [ NaN ; NaN ; NaN ];

%-- Image #162:
omc_162 = [ NaN ; NaN ; NaN ];
Tc_162  = [ NaN ; NaN ; NaN ];
omc_error_162 = [ NaN ; NaN ; NaN ];
Tc_error_162  = [ NaN ; NaN ; NaN ];

%-- Image #163:
omc_163 = [ NaN ; NaN ; NaN ];
Tc_163  = [ NaN ; NaN ; NaN ];
omc_error_163 = [ NaN ; NaN ; NaN ];
Tc_error_163  = [ NaN ; NaN ; NaN ];

%-- Image #164:
omc_164 = [ NaN ; NaN ; NaN ];
Tc_164  = [ NaN ; NaN ; NaN ];
omc_error_164 = [ NaN ; NaN ; NaN ];
Tc_error_164  = [ NaN ; NaN ; NaN ];

%-- Image #165:
omc_165 = [ NaN ; NaN ; NaN ];
Tc_165  = [ NaN ; NaN ; NaN ];
omc_error_165 = [ NaN ; NaN ; NaN ];
Tc_error_165  = [ NaN ; NaN ; NaN ];

%-- Image #166:
omc_166 = [ -2.291005e+00 ; -2.050689e+00 ; -1.077580e-01 ];
Tc_166  = [ -1.614802e+02 ; -2.312204e+02 ; 1.154229e+03 ];
omc_error_166 = [ 3.711344e-03 ; 3.422507e-03 ; 7.961856e-03 ];
Tc_error_166  = [ 4.611523e+00 ; 3.689477e+00 ; 4.347467e+00 ];

%-- Image #167:
omc_167 = [ NaN ; NaN ; NaN ];
Tc_167  = [ NaN ; NaN ; NaN ];
omc_error_167 = [ NaN ; NaN ; NaN ];
Tc_error_167  = [ NaN ; NaN ; NaN ];

%-- Image #168:
omc_168 = [ NaN ; NaN ; NaN ];
Tc_168  = [ NaN ; NaN ; NaN ];
omc_error_168 = [ NaN ; NaN ; NaN ];
Tc_error_168  = [ NaN ; NaN ; NaN ];

%-- Image #169:
omc_169 = [ NaN ; NaN ; NaN ];
Tc_169  = [ NaN ; NaN ; NaN ];
omc_error_169 = [ NaN ; NaN ; NaN ];
Tc_error_169  = [ NaN ; NaN ; NaN ];

%-- Image #170:
omc_170 = [ NaN ; NaN ; NaN ];
Tc_170  = [ NaN ; NaN ; NaN ];
omc_error_170 = [ NaN ; NaN ; NaN ];
Tc_error_170  = [ NaN ; NaN ; NaN ];

%-- Image #171:
omc_171 = [ NaN ; NaN ; NaN ];
Tc_171  = [ NaN ; NaN ; NaN ];
omc_error_171 = [ NaN ; NaN ; NaN ];
Tc_error_171  = [ NaN ; NaN ; NaN ];

%-- Image #172:
omc_172 = [ NaN ; NaN ; NaN ];
Tc_172  = [ NaN ; NaN ; NaN ];
omc_error_172 = [ NaN ; NaN ; NaN ];
Tc_error_172  = [ NaN ; NaN ; NaN ];

%-- Image #173:
omc_173 = [ NaN ; NaN ; NaN ];
Tc_173  = [ NaN ; NaN ; NaN ];
omc_error_173 = [ NaN ; NaN ; NaN ];
Tc_error_173  = [ NaN ; NaN ; NaN ];

%-- Image #174:
omc_174 = [ NaN ; NaN ; NaN ];
Tc_174  = [ NaN ; NaN ; NaN ];
omc_error_174 = [ NaN ; NaN ; NaN ];
Tc_error_174  = [ NaN ; NaN ; NaN ];

%-- Image #175:
omc_175 = [ NaN ; NaN ; NaN ];
Tc_175  = [ NaN ; NaN ; NaN ];
omc_error_175 = [ NaN ; NaN ; NaN ];
Tc_error_175  = [ NaN ; NaN ; NaN ];

%-- Image #176:
omc_176 = [ NaN ; NaN ; NaN ];
Tc_176  = [ NaN ; NaN ; NaN ];
omc_error_176 = [ NaN ; NaN ; NaN ];
Tc_error_176  = [ NaN ; NaN ; NaN ];

%-- Image #177:
omc_177 = [ NaN ; NaN ; NaN ];
Tc_177  = [ NaN ; NaN ; NaN ];
omc_error_177 = [ NaN ; NaN ; NaN ];
Tc_error_177  = [ NaN ; NaN ; NaN ];

%-- Image #178:
omc_178 = [ NaN ; NaN ; NaN ];
Tc_178  = [ NaN ; NaN ; NaN ];
omc_error_178 = [ NaN ; NaN ; NaN ];
Tc_error_178  = [ NaN ; NaN ; NaN ];

%-- Image #179:
omc_179 = [ NaN ; NaN ; NaN ];
Tc_179  = [ NaN ; NaN ; NaN ];
omc_error_179 = [ NaN ; NaN ; NaN ];
Tc_error_179  = [ NaN ; NaN ; NaN ];

%-- Image #180:
omc_180 = [ NaN ; NaN ; NaN ];
Tc_180  = [ NaN ; NaN ; NaN ];
omc_error_180 = [ NaN ; NaN ; NaN ];
Tc_error_180  = [ NaN ; NaN ; NaN ];

%-- Image #181:
omc_181 = [ NaN ; NaN ; NaN ];
Tc_181  = [ NaN ; NaN ; NaN ];
omc_error_181 = [ NaN ; NaN ; NaN ];
Tc_error_181  = [ NaN ; NaN ; NaN ];

%-- Image #182:
omc_182 = [ NaN ; NaN ; NaN ];
Tc_182  = [ NaN ; NaN ; NaN ];
omc_error_182 = [ NaN ; NaN ; NaN ];
Tc_error_182  = [ NaN ; NaN ; NaN ];

%-- Image #183:
omc_183 = [ NaN ; NaN ; NaN ];
Tc_183  = [ NaN ; NaN ; NaN ];
omc_error_183 = [ NaN ; NaN ; NaN ];
Tc_error_183  = [ NaN ; NaN ; NaN ];

%-- Image #184:
omc_184 = [ NaN ; NaN ; NaN ];
Tc_184  = [ NaN ; NaN ; NaN ];
omc_error_184 = [ NaN ; NaN ; NaN ];
Tc_error_184  = [ NaN ; NaN ; NaN ];

%-- Image #185:
omc_185 = [ NaN ; NaN ; NaN ];
Tc_185  = [ NaN ; NaN ; NaN ];
omc_error_185 = [ NaN ; NaN ; NaN ];
Tc_error_185  = [ NaN ; NaN ; NaN ];

%-- Image #186:
omc_186 = [ NaN ; NaN ; NaN ];
Tc_186  = [ NaN ; NaN ; NaN ];
omc_error_186 = [ NaN ; NaN ; NaN ];
Tc_error_186  = [ NaN ; NaN ; NaN ];

%-- Image #187:
omc_187 = [ NaN ; NaN ; NaN ];
Tc_187  = [ NaN ; NaN ; NaN ];
omc_error_187 = [ NaN ; NaN ; NaN ];
Tc_error_187  = [ NaN ; NaN ; NaN ];

%-- Image #188:
omc_188 = [ NaN ; NaN ; NaN ];
Tc_188  = [ NaN ; NaN ; NaN ];
omc_error_188 = [ NaN ; NaN ; NaN ];
Tc_error_188  = [ NaN ; NaN ; NaN ];

%-- Image #189:
omc_189 = [ NaN ; NaN ; NaN ];
Tc_189  = [ NaN ; NaN ; NaN ];
omc_error_189 = [ NaN ; NaN ; NaN ];
Tc_error_189  = [ NaN ; NaN ; NaN ];

%-- Image #190:
omc_190 = [ NaN ; NaN ; NaN ];
Tc_190  = [ NaN ; NaN ; NaN ];
omc_error_190 = [ NaN ; NaN ; NaN ];
Tc_error_190  = [ NaN ; NaN ; NaN ];

%-- Image #191:
omc_191 = [ NaN ; NaN ; NaN ];
Tc_191  = [ NaN ; NaN ; NaN ];
omc_error_191 = [ NaN ; NaN ; NaN ];
Tc_error_191  = [ NaN ; NaN ; NaN ];

%-- Image #192:
omc_192 = [ NaN ; NaN ; NaN ];
Tc_192  = [ NaN ; NaN ; NaN ];
omc_error_192 = [ NaN ; NaN ; NaN ];
Tc_error_192  = [ NaN ; NaN ; NaN ];

%-- Image #193:
omc_193 = [ NaN ; NaN ; NaN ];
Tc_193  = [ NaN ; NaN ; NaN ];
omc_error_193 = [ NaN ; NaN ; NaN ];
Tc_error_193  = [ NaN ; NaN ; NaN ];

%-- Image #194:
omc_194 = [ NaN ; NaN ; NaN ];
Tc_194  = [ NaN ; NaN ; NaN ];
omc_error_194 = [ NaN ; NaN ; NaN ];
Tc_error_194  = [ NaN ; NaN ; NaN ];

%-- Image #195:
omc_195 = [ NaN ; NaN ; NaN ];
Tc_195  = [ NaN ; NaN ; NaN ];
omc_error_195 = [ NaN ; NaN ; NaN ];
Tc_error_195  = [ NaN ; NaN ; NaN ];

%-- Image #196:
omc_196 = [ -1.744395e+00 ; -1.741386e+00 ; 7.938814e-01 ];
Tc_196  = [ -8.142042e+01 ; -2.336559e+02 ; 1.360236e+03 ];
omc_error_196 = [ 3.454819e-03 ; 2.627504e-03 ; 4.806091e-03 ];
Tc_error_196  = [ 5.413453e+00 ; 4.300725e+00 ; 4.137538e+00 ];

%-- Image #197:
omc_197 = [ NaN ; NaN ; NaN ];
Tc_197  = [ NaN ; NaN ; NaN ];
omc_error_197 = [ NaN ; NaN ; NaN ];
Tc_error_197  = [ NaN ; NaN ; NaN ];

%-- Image #198:
omc_198 = [ NaN ; NaN ; NaN ];
Tc_198  = [ NaN ; NaN ; NaN ];
omc_error_198 = [ NaN ; NaN ; NaN ];
Tc_error_198  = [ NaN ; NaN ; NaN ];

%-- Image #199:
omc_199 = [ NaN ; NaN ; NaN ];
Tc_199  = [ NaN ; NaN ; NaN ];
omc_error_199 = [ NaN ; NaN ; NaN ];
Tc_error_199  = [ NaN ; NaN ; NaN ];

%-- Image #200:
omc_200 = [ NaN ; NaN ; NaN ];
Tc_200  = [ NaN ; NaN ; NaN ];
omc_error_200 = [ NaN ; NaN ; NaN ];
Tc_error_200  = [ NaN ; NaN ; NaN ];

%-- Image #201:
omc_201 = [ NaN ; NaN ; NaN ];
Tc_201  = [ NaN ; NaN ; NaN ];
omc_error_201 = [ NaN ; NaN ; NaN ];
Tc_error_201  = [ NaN ; NaN ; NaN ];

%-- Image #202:
omc_202 = [ NaN ; NaN ; NaN ];
Tc_202  = [ NaN ; NaN ; NaN ];
omc_error_202 = [ NaN ; NaN ; NaN ];
Tc_error_202  = [ NaN ; NaN ; NaN ];

%-- Image #203:
omc_203 = [ NaN ; NaN ; NaN ];
Tc_203  = [ NaN ; NaN ; NaN ];
omc_error_203 = [ NaN ; NaN ; NaN ];
Tc_error_203  = [ NaN ; NaN ; NaN ];

%-- Image #204:
omc_204 = [ NaN ; NaN ; NaN ];
Tc_204  = [ NaN ; NaN ; NaN ];
omc_error_204 = [ NaN ; NaN ; NaN ];
Tc_error_204  = [ NaN ; NaN ; NaN ];

%-- Image #205:
omc_205 = [ NaN ; NaN ; NaN ];
Tc_205  = [ NaN ; NaN ; NaN ];
omc_error_205 = [ NaN ; NaN ; NaN ];
Tc_error_205  = [ NaN ; NaN ; NaN ];

%-- Image #206:
omc_206 = [ NaN ; NaN ; NaN ];
Tc_206  = [ NaN ; NaN ; NaN ];
omc_error_206 = [ NaN ; NaN ; NaN ];
Tc_error_206  = [ NaN ; NaN ; NaN ];

%-- Image #207:
omc_207 = [ NaN ; NaN ; NaN ];
Tc_207  = [ NaN ; NaN ; NaN ];
omc_error_207 = [ NaN ; NaN ; NaN ];
Tc_error_207  = [ NaN ; NaN ; NaN ];

%-- Image #208:
omc_208 = [ NaN ; NaN ; NaN ];
Tc_208  = [ NaN ; NaN ; NaN ];
omc_error_208 = [ NaN ; NaN ; NaN ];
Tc_error_208  = [ NaN ; NaN ; NaN ];

%-- Image #209:
omc_209 = [ NaN ; NaN ; NaN ];
Tc_209  = [ NaN ; NaN ; NaN ];
omc_error_209 = [ NaN ; NaN ; NaN ];
Tc_error_209  = [ NaN ; NaN ; NaN ];

%-- Image #210:
omc_210 = [ NaN ; NaN ; NaN ];
Tc_210  = [ NaN ; NaN ; NaN ];
omc_error_210 = [ NaN ; NaN ; NaN ];
Tc_error_210  = [ NaN ; NaN ; NaN ];

%-- Image #211:
omc_211 = [ -2.137505e+00 ; -2.139076e+00 ; 8.431944e-02 ];
Tc_211  = [ -1.465737e+02 ; -2.385191e+02 ; 1.182449e+03 ];
omc_error_211 = [ 3.517578e-03 ; 3.571503e-03 ; 7.878554e-03 ];
Tc_error_211  = [ 4.693506e+00 ; 3.745978e+00 ; 4.349386e+00 ];

%-- Image #212:
omc_212 = [ NaN ; NaN ; NaN ];
Tc_212  = [ NaN ; NaN ; NaN ];
omc_error_212 = [ NaN ; NaN ; NaN ];
Tc_error_212  = [ NaN ; NaN ; NaN ];

%-- Image #213:
omc_213 = [ NaN ; NaN ; NaN ];
Tc_213  = [ NaN ; NaN ; NaN ];
omc_error_213 = [ NaN ; NaN ; NaN ];
Tc_error_213  = [ NaN ; NaN ; NaN ];

%-- Image #214:
omc_214 = [ NaN ; NaN ; NaN ];
Tc_214  = [ NaN ; NaN ; NaN ];
omc_error_214 = [ NaN ; NaN ; NaN ];
Tc_error_214  = [ NaN ; NaN ; NaN ];

%-- Image #215:
omc_215 = [ NaN ; NaN ; NaN ];
Tc_215  = [ NaN ; NaN ; NaN ];
omc_error_215 = [ NaN ; NaN ; NaN ];
Tc_error_215  = [ NaN ; NaN ; NaN ];

%-- Image #216:
omc_216 = [ NaN ; NaN ; NaN ];
Tc_216  = [ NaN ; NaN ; NaN ];
omc_error_216 = [ NaN ; NaN ; NaN ];
Tc_error_216  = [ NaN ; NaN ; NaN ];

%-- Image #217:
omc_217 = [ NaN ; NaN ; NaN ];
Tc_217  = [ NaN ; NaN ; NaN ];
omc_error_217 = [ NaN ; NaN ; NaN ];
Tc_error_217  = [ NaN ; NaN ; NaN ];

%-- Image #218:
omc_218 = [ NaN ; NaN ; NaN ];
Tc_218  = [ NaN ; NaN ; NaN ];
omc_error_218 = [ NaN ; NaN ; NaN ];
Tc_error_218  = [ NaN ; NaN ; NaN ];

%-- Image #219:
omc_219 = [ NaN ; NaN ; NaN ];
Tc_219  = [ NaN ; NaN ; NaN ];
omc_error_219 = [ NaN ; NaN ; NaN ];
Tc_error_219  = [ NaN ; NaN ; NaN ];

%-- Image #220:
omc_220 = [ NaN ; NaN ; NaN ];
Tc_220  = [ NaN ; NaN ; NaN ];
omc_error_220 = [ NaN ; NaN ; NaN ];
Tc_error_220  = [ NaN ; NaN ; NaN ];

%-- Image #221:
omc_221 = [ NaN ; NaN ; NaN ];
Tc_221  = [ NaN ; NaN ; NaN ];
omc_error_221 = [ NaN ; NaN ; NaN ];
Tc_error_221  = [ NaN ; NaN ; NaN ];

%-- Image #222:
omc_222 = [ NaN ; NaN ; NaN ];
Tc_222  = [ NaN ; NaN ; NaN ];
omc_error_222 = [ NaN ; NaN ; NaN ];
Tc_error_222  = [ NaN ; NaN ; NaN ];

%-- Image #223:
omc_223 = [ NaN ; NaN ; NaN ];
Tc_223  = [ NaN ; NaN ; NaN ];
omc_error_223 = [ NaN ; NaN ; NaN ];
Tc_error_223  = [ NaN ; NaN ; NaN ];

%-- Image #224:
omc_224 = [ NaN ; NaN ; NaN ];
Tc_224  = [ NaN ; NaN ; NaN ];
omc_error_224 = [ NaN ; NaN ; NaN ];
Tc_error_224  = [ NaN ; NaN ; NaN ];

%-- Image #225:
omc_225 = [ NaN ; NaN ; NaN ];
Tc_225  = [ NaN ; NaN ; NaN ];
omc_error_225 = [ NaN ; NaN ; NaN ];
Tc_error_225  = [ NaN ; NaN ; NaN ];

%-- Image #226:
omc_226 = [ NaN ; NaN ; NaN ];
Tc_226  = [ NaN ; NaN ; NaN ];
omc_error_226 = [ NaN ; NaN ; NaN ];
Tc_error_226  = [ NaN ; NaN ; NaN ];

%-- Image #227:
omc_227 = [ NaN ; NaN ; NaN ];
Tc_227  = [ NaN ; NaN ; NaN ];
omc_error_227 = [ NaN ; NaN ; NaN ];
Tc_error_227  = [ NaN ; NaN ; NaN ];

%-- Image #228:
omc_228 = [ NaN ; NaN ; NaN ];
Tc_228  = [ NaN ; NaN ; NaN ];
omc_error_228 = [ NaN ; NaN ; NaN ];
Tc_error_228  = [ NaN ; NaN ; NaN ];

%-- Image #229:
omc_229 = [ NaN ; NaN ; NaN ];
Tc_229  = [ NaN ; NaN ; NaN ];
omc_error_229 = [ NaN ; NaN ; NaN ];
Tc_error_229  = [ NaN ; NaN ; NaN ];

%-- Image #230:
omc_230 = [ NaN ; NaN ; NaN ];
Tc_230  = [ NaN ; NaN ; NaN ];
omc_error_230 = [ NaN ; NaN ; NaN ];
Tc_error_230  = [ NaN ; NaN ; NaN ];

%-- Image #231:
omc_231 = [ NaN ; NaN ; NaN ];
Tc_231  = [ NaN ; NaN ; NaN ];
omc_error_231 = [ NaN ; NaN ; NaN ];
Tc_error_231  = [ NaN ; NaN ; NaN ];

%-- Image #232:
omc_232 = [ NaN ; NaN ; NaN ];
Tc_232  = [ NaN ; NaN ; NaN ];
omc_error_232 = [ NaN ; NaN ; NaN ];
Tc_error_232  = [ NaN ; NaN ; NaN ];

%-- Image #233:
omc_233 = [ NaN ; NaN ; NaN ];
Tc_233  = [ NaN ; NaN ; NaN ];
omc_error_233 = [ NaN ; NaN ; NaN ];
Tc_error_233  = [ NaN ; NaN ; NaN ];

%-- Image #234:
omc_234 = [ NaN ; NaN ; NaN ];
Tc_234  = [ NaN ; NaN ; NaN ];
omc_error_234 = [ NaN ; NaN ; NaN ];
Tc_error_234  = [ NaN ; NaN ; NaN ];

%-- Image #235:
omc_235 = [ NaN ; NaN ; NaN ];
Tc_235  = [ NaN ; NaN ; NaN ];
omc_error_235 = [ NaN ; NaN ; NaN ];
Tc_error_235  = [ NaN ; NaN ; NaN ];

%-- Image #236:
omc_236 = [ NaN ; NaN ; NaN ];
Tc_236  = [ NaN ; NaN ; NaN ];
omc_error_236 = [ NaN ; NaN ; NaN ];
Tc_error_236  = [ NaN ; NaN ; NaN ];

%-- Image #237:
omc_237 = [ NaN ; NaN ; NaN ];
Tc_237  = [ NaN ; NaN ; NaN ];
omc_error_237 = [ NaN ; NaN ; NaN ];
Tc_error_237  = [ NaN ; NaN ; NaN ];

%-- Image #238:
omc_238 = [ NaN ; NaN ; NaN ];
Tc_238  = [ NaN ; NaN ; NaN ];
omc_error_238 = [ NaN ; NaN ; NaN ];
Tc_error_238  = [ NaN ; NaN ; NaN ];

%-- Image #239:
omc_239 = [ NaN ; NaN ; NaN ];
Tc_239  = [ NaN ; NaN ; NaN ];
omc_error_239 = [ NaN ; NaN ; NaN ];
Tc_error_239  = [ NaN ; NaN ; NaN ];

%-- Image #240:
omc_240 = [ NaN ; NaN ; NaN ];
Tc_240  = [ NaN ; NaN ; NaN ];
omc_error_240 = [ NaN ; NaN ; NaN ];
Tc_error_240  = [ NaN ; NaN ; NaN ];

%-- Image #241:
omc_241 = [ NaN ; NaN ; NaN ];
Tc_241  = [ NaN ; NaN ; NaN ];
omc_error_241 = [ NaN ; NaN ; NaN ];
Tc_error_241  = [ NaN ; NaN ; NaN ];

%-- Image #242:
omc_242 = [ NaN ; NaN ; NaN ];
Tc_242  = [ NaN ; NaN ; NaN ];
omc_error_242 = [ NaN ; NaN ; NaN ];
Tc_error_242  = [ NaN ; NaN ; NaN ];

%-- Image #243:
omc_243 = [ NaN ; NaN ; NaN ];
Tc_243  = [ NaN ; NaN ; NaN ];
omc_error_243 = [ NaN ; NaN ; NaN ];
Tc_error_243  = [ NaN ; NaN ; NaN ];

%-- Image #244:
omc_244 = [ NaN ; NaN ; NaN ];
Tc_244  = [ NaN ; NaN ; NaN ];
omc_error_244 = [ NaN ; NaN ; NaN ];
Tc_error_244  = [ NaN ; NaN ; NaN ];

%-- Image #245:
omc_245 = [ NaN ; NaN ; NaN ];
Tc_245  = [ NaN ; NaN ; NaN ];
omc_error_245 = [ NaN ; NaN ; NaN ];
Tc_error_245  = [ NaN ; NaN ; NaN ];

%-- Image #246:
omc_246 = [ NaN ; NaN ; NaN ];
Tc_246  = [ NaN ; NaN ; NaN ];
omc_error_246 = [ NaN ; NaN ; NaN ];
Tc_error_246  = [ NaN ; NaN ; NaN ];

%-- Image #247:
omc_247 = [ NaN ; NaN ; NaN ];
Tc_247  = [ NaN ; NaN ; NaN ];
omc_error_247 = [ NaN ; NaN ; NaN ];
Tc_error_247  = [ NaN ; NaN ; NaN ];

%-- Image #248:
omc_248 = [ NaN ; NaN ; NaN ];
Tc_248  = [ NaN ; NaN ; NaN ];
omc_error_248 = [ NaN ; NaN ; NaN ];
Tc_error_248  = [ NaN ; NaN ; NaN ];

%-- Image #249:
omc_249 = [ NaN ; NaN ; NaN ];
Tc_249  = [ NaN ; NaN ; NaN ];
omc_error_249 = [ NaN ; NaN ; NaN ];
Tc_error_249  = [ NaN ; NaN ; NaN ];

%-- Image #250:
omc_250 = [ NaN ; NaN ; NaN ];
Tc_250  = [ NaN ; NaN ; NaN ];
omc_error_250 = [ NaN ; NaN ; NaN ];
Tc_error_250  = [ NaN ; NaN ; NaN ];

%-- Image #251:
omc_251 = [ NaN ; NaN ; NaN ];
Tc_251  = [ NaN ; NaN ; NaN ];
omc_error_251 = [ NaN ; NaN ; NaN ];
Tc_error_251  = [ NaN ; NaN ; NaN ];

%-- Image #252:
omc_252 = [ NaN ; NaN ; NaN ];
Tc_252  = [ NaN ; NaN ; NaN ];
omc_error_252 = [ NaN ; NaN ; NaN ];
Tc_error_252  = [ NaN ; NaN ; NaN ];

%-- Image #253:
omc_253 = [ NaN ; NaN ; NaN ];
Tc_253  = [ NaN ; NaN ; NaN ];
omc_error_253 = [ NaN ; NaN ; NaN ];
Tc_error_253  = [ NaN ; NaN ; NaN ];

%-- Image #254:
omc_254 = [ NaN ; NaN ; NaN ];
Tc_254  = [ NaN ; NaN ; NaN ];
omc_error_254 = [ NaN ; NaN ; NaN ];
Tc_error_254  = [ NaN ; NaN ; NaN ];

%-- Image #255:
omc_255 = [ NaN ; NaN ; NaN ];
Tc_255  = [ NaN ; NaN ; NaN ];
omc_error_255 = [ NaN ; NaN ; NaN ];
Tc_error_255  = [ NaN ; NaN ; NaN ];

%-- Image #256:
omc_256 = [ -2.058349e+00 ; -1.996653e+00 ; -4.803411e-01 ];
Tc_256  = [ -1.559295e+02 ; -2.211752e+02 ; 1.053415e+03 ];
omc_error_256 = [ 2.391436e-03 ; 3.110069e-03 ; 5.960450e-03 ];
Tc_error_256  = [ 4.218799e+00 ; 3.359757e+00 ; 4.023022e+00 ];

%-- Image #257:
omc_257 = [ NaN ; NaN ; NaN ];
Tc_257  = [ NaN ; NaN ; NaN ];
omc_error_257 = [ NaN ; NaN ; NaN ];
Tc_error_257  = [ NaN ; NaN ; NaN ];

%-- Image #258:
omc_258 = [ NaN ; NaN ; NaN ];
Tc_258  = [ NaN ; NaN ; NaN ];
omc_error_258 = [ NaN ; NaN ; NaN ];
Tc_error_258  = [ NaN ; NaN ; NaN ];

%-- Image #259:
omc_259 = [ NaN ; NaN ; NaN ];
Tc_259  = [ NaN ; NaN ; NaN ];
omc_error_259 = [ NaN ; NaN ; NaN ];
Tc_error_259  = [ NaN ; NaN ; NaN ];

%-- Image #260:
omc_260 = [ NaN ; NaN ; NaN ];
Tc_260  = [ NaN ; NaN ; NaN ];
omc_error_260 = [ NaN ; NaN ; NaN ];
Tc_error_260  = [ NaN ; NaN ; NaN ];

%-- Image #261:
omc_261 = [ NaN ; NaN ; NaN ];
Tc_261  = [ NaN ; NaN ; NaN ];
omc_error_261 = [ NaN ; NaN ; NaN ];
Tc_error_261  = [ NaN ; NaN ; NaN ];

%-- Image #262:
omc_262 = [ NaN ; NaN ; NaN ];
Tc_262  = [ NaN ; NaN ; NaN ];
omc_error_262 = [ NaN ; NaN ; NaN ];
Tc_error_262  = [ NaN ; NaN ; NaN ];

%-- Image #263:
omc_263 = [ NaN ; NaN ; NaN ];
Tc_263  = [ NaN ; NaN ; NaN ];
omc_error_263 = [ NaN ; NaN ; NaN ];
Tc_error_263  = [ NaN ; NaN ; NaN ];

%-- Image #264:
omc_264 = [ NaN ; NaN ; NaN ];
Tc_264  = [ NaN ; NaN ; NaN ];
omc_error_264 = [ NaN ; NaN ; NaN ];
Tc_error_264  = [ NaN ; NaN ; NaN ];

%-- Image #265:
omc_265 = [ NaN ; NaN ; NaN ];
Tc_265  = [ NaN ; NaN ; NaN ];
omc_error_265 = [ NaN ; NaN ; NaN ];
Tc_error_265  = [ NaN ; NaN ; NaN ];

%-- Image #266:
omc_266 = [ NaN ; NaN ; NaN ];
Tc_266  = [ NaN ; NaN ; NaN ];
omc_error_266 = [ NaN ; NaN ; NaN ];
Tc_error_266  = [ NaN ; NaN ; NaN ];

%-- Image #267:
omc_267 = [ NaN ; NaN ; NaN ];
Tc_267  = [ NaN ; NaN ; NaN ];
omc_error_267 = [ NaN ; NaN ; NaN ];
Tc_error_267  = [ NaN ; NaN ; NaN ];

%-- Image #268:
omc_268 = [ NaN ; NaN ; NaN ];
Tc_268  = [ NaN ; NaN ; NaN ];
omc_error_268 = [ NaN ; NaN ; NaN ];
Tc_error_268  = [ NaN ; NaN ; NaN ];

%-- Image #269:
omc_269 = [ NaN ; NaN ; NaN ];
Tc_269  = [ NaN ; NaN ; NaN ];
omc_error_269 = [ NaN ; NaN ; NaN ];
Tc_error_269  = [ NaN ; NaN ; NaN ];

%-- Image #270:
omc_270 = [ NaN ; NaN ; NaN ];
Tc_270  = [ NaN ; NaN ; NaN ];
omc_error_270 = [ NaN ; NaN ; NaN ];
Tc_error_270  = [ NaN ; NaN ; NaN ];

%-- Image #271:
omc_271 = [ 2.033144e+00 ; 1.908233e+00 ; -3.790776e-01 ];
Tc_271  = [ -1.653268e+02 ; -2.342939e+02 ; 1.218458e+03 ];
omc_error_271 = [ 2.333956e-03 ; 3.165938e-03 ; 5.416491e-03 ];
Tc_error_271  = [ 4.842822e+00 ; 3.838340e+00 ; 4.289303e+00 ];

%-- Image #272:
omc_272 = [ NaN ; NaN ; NaN ];
Tc_272  = [ NaN ; NaN ; NaN ];
omc_error_272 = [ NaN ; NaN ; NaN ];
Tc_error_272  = [ NaN ; NaN ; NaN ];

%-- Image #273:
omc_273 = [ NaN ; NaN ; NaN ];
Tc_273  = [ NaN ; NaN ; NaN ];
omc_error_273 = [ NaN ; NaN ; NaN ];
Tc_error_273  = [ NaN ; NaN ; NaN ];

%-- Image #274:
omc_274 = [ NaN ; NaN ; NaN ];
Tc_274  = [ NaN ; NaN ; NaN ];
omc_error_274 = [ NaN ; NaN ; NaN ];
Tc_error_274  = [ NaN ; NaN ; NaN ];

%-- Image #275:
omc_275 = [ NaN ; NaN ; NaN ];
Tc_275  = [ NaN ; NaN ; NaN ];
omc_error_275 = [ NaN ; NaN ; NaN ];
Tc_error_275  = [ NaN ; NaN ; NaN ];

%-- Image #276:
omc_276 = [ NaN ; NaN ; NaN ];
Tc_276  = [ NaN ; NaN ; NaN ];
omc_error_276 = [ NaN ; NaN ; NaN ];
Tc_error_276  = [ NaN ; NaN ; NaN ];

%-- Image #277:
omc_277 = [ NaN ; NaN ; NaN ];
Tc_277  = [ NaN ; NaN ; NaN ];
omc_error_277 = [ NaN ; NaN ; NaN ];
Tc_error_277  = [ NaN ; NaN ; NaN ];

%-- Image #278:
omc_278 = [ NaN ; NaN ; NaN ];
Tc_278  = [ NaN ; NaN ; NaN ];
omc_error_278 = [ NaN ; NaN ; NaN ];
Tc_error_278  = [ NaN ; NaN ; NaN ];

%-- Image #279:
omc_279 = [ NaN ; NaN ; NaN ];
Tc_279  = [ NaN ; NaN ; NaN ];
omc_error_279 = [ NaN ; NaN ; NaN ];
Tc_error_279  = [ NaN ; NaN ; NaN ];

%-- Image #280:
omc_280 = [ NaN ; NaN ; NaN ];
Tc_280  = [ NaN ; NaN ; NaN ];
omc_error_280 = [ NaN ; NaN ; NaN ];
Tc_error_280  = [ NaN ; NaN ; NaN ];

%-- Image #281:
omc_281 = [ NaN ; NaN ; NaN ];
Tc_281  = [ NaN ; NaN ; NaN ];
omc_error_281 = [ NaN ; NaN ; NaN ];
Tc_error_281  = [ NaN ; NaN ; NaN ];

%-- Image #282:
omc_282 = [ NaN ; NaN ; NaN ];
Tc_282  = [ NaN ; NaN ; NaN ];
omc_error_282 = [ NaN ; NaN ; NaN ];
Tc_error_282  = [ NaN ; NaN ; NaN ];

%-- Image #283:
omc_283 = [ NaN ; NaN ; NaN ];
Tc_283  = [ NaN ; NaN ; NaN ];
omc_error_283 = [ NaN ; NaN ; NaN ];
Tc_error_283  = [ NaN ; NaN ; NaN ];

%-- Image #284:
omc_284 = [ NaN ; NaN ; NaN ];
Tc_284  = [ NaN ; NaN ; NaN ];
omc_error_284 = [ NaN ; NaN ; NaN ];
Tc_error_284  = [ NaN ; NaN ; NaN ];

%-- Image #285:
omc_285 = [ NaN ; NaN ; NaN ];
Tc_285  = [ NaN ; NaN ; NaN ];
omc_error_285 = [ NaN ; NaN ; NaN ];
Tc_error_285  = [ NaN ; NaN ; NaN ];

%-- Image #286:
omc_286 = [ 1.824129e+00 ; 1.676794e+00 ; -6.652014e-01 ];
Tc_286  = [ -1.612461e+02 ; -1.989236e+02 ; 1.287265e+03 ];
omc_error_286 = [ 2.417046e-03 ; 3.343868e-03 ; 4.776917e-03 ];
Tc_error_286  = [ 5.106980e+00 ; 4.062999e+00 ; 4.323017e+00 ];

%-- Image #287:
omc_287 = [ NaN ; NaN ; NaN ];
Tc_287  = [ NaN ; NaN ; NaN ];
omc_error_287 = [ NaN ; NaN ; NaN ];
Tc_error_287  = [ NaN ; NaN ; NaN ];

%-- Image #288:
omc_288 = [ NaN ; NaN ; NaN ];
Tc_288  = [ NaN ; NaN ; NaN ];
omc_error_288 = [ NaN ; NaN ; NaN ];
Tc_error_288  = [ NaN ; NaN ; NaN ];

%-- Image #289:
omc_289 = [ NaN ; NaN ; NaN ];
Tc_289  = [ NaN ; NaN ; NaN ];
omc_error_289 = [ NaN ; NaN ; NaN ];
Tc_error_289  = [ NaN ; NaN ; NaN ];

%-- Image #290:
omc_290 = [ NaN ; NaN ; NaN ];
Tc_290  = [ NaN ; NaN ; NaN ];
omc_error_290 = [ NaN ; NaN ; NaN ];
Tc_error_290  = [ NaN ; NaN ; NaN ];

%-- Image #291:
omc_291 = [ NaN ; NaN ; NaN ];
Tc_291  = [ NaN ; NaN ; NaN ];
omc_error_291 = [ NaN ; NaN ; NaN ];
Tc_error_291  = [ NaN ; NaN ; NaN ];

