% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1113.617301530191980 ; 1114.952337051343420 ];

%-- Principal point:
cc = [ 507.875994179966710 ; 481.819527493916723 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.145656912036092 ; 0.241082881694422 ; -0.003294233798463 ; 0.000130222953785 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 1.961421941580207 ; 1.959324005605293 ];

%-- Principal point uncertainty:
cc_error = [ 2.967904814453548 ; 2.167327752153262 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.008355142490078 ; 0.059866047842027 ; 0.000483187953934 ; 0.000621490434635 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -1.108739e+00 ; -7.110949e-01 ; 2.777310e+00 ];
Tc_1  = [ 9.196909e+02 ; 4.836920e+02 ; 3.956411e+03 ];
omc_error_1 = [ 2.829053e-03 ; 3.024458e-03 ; 6.364187e-03 ];
Tc_error_1  = [ 2.948003e+00 ; 2.160428e+00 ; 2.299121e+00 ];

