% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1115.598099700625880 ; 1116.946920449617664 ];

%-- Principal point:
cc = [ 536.483376903490466 ; 474.583801478455769 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.150684719299177 ; 0.340566537843655 ; -0.001338669255467 ; 0.003097267579837 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 3.164342485906628 ; 3.148997628192741 ];

%-- Principal point uncertainty:
cc_error = [ 4.304364643937538 ; 3.175074294950391 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.016072962990134 ; 0.188191651019270 ; 0.000699289131527 ; 0.000898098033089 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -2.548475e+00 ; -1.312043e-01 ; 1.047160e+00 ];
Tc_1  = [ -4.447859e+02 ; 5.247126e+02 ; 4.368168e+03 ];
omc_error_1 = [ 3.666770e-03 ; 3.474281e-03 ; 7.747718e-03 ];
Tc_error_1  = [ 4.677824e+00 ; 3.445187e+00 ; 3.686189e+00 ];

